Documentation
¶
Overview ¶
Package consul implements the consul configuration center integration, fulfilling the core/config/Source interface.
Index ¶
Constants ¶
const ( // Name of the configuration source. Name = "consul" // Priority of this source. Higher than files, allowing remote overrides. Priority = 11 )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
Client string `json:"client"` // The name of the consul client to use from stores
Delimiter string `json:"delimiter"` // Path separator, usually "/"
}
Config defines the settings for the Consul source implementation.
type Consul ¶
type Consul struct {
// contains filtered or unexported fields
}
Consul manages the connection to the Consul KV store and handles configuration synchronization.
func (*Consul) Disconnect ¶
func (s *Consul) Disconnect()
Disconnect cleans up any resources if the source is closed.
Click to show internal directories.
Click to hide internal directories.